==> nextcloud-26.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/uk.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Майстерня",
    "Dashboard app" : "Застосунок з панеллю віджетів ",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Почніть свій день поінформовано\n\nІнформаційна панель Nextcloud - це ваша відправна точка дня, яка дає вам огляд майбутніх зустрічей, термінових електронних листів, повідомлень в чаті, призначених завдань, останніх твітів і багато іншого! Користувачі можуть додавати віджети, які їм подобаються, і змінювати фон на свій смак.",
    "\"{title} icon\"" : "\"{title} \"іконка\"",
    "Customize" : "Редагувати",
    "Edit widgets" : "Редагувати віджети",
    "Get more widgets from the App Store" : "Більше віджетів у каталозі застосунків",
    "Weather service" : "Погода",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Для забезпечення вашої конфіденційності дані про погоду запитуються вашим сервером Nextcloud від вашого імені, тому служба погоди не отримує особисту інформацію.",
    "Weather data from Met.no" : "Дані про погоду з Met.no",
    "geocoding with Nominatim" : "геокодування за допомогою Nominatim",
    "elevation data from OpenTopoData" : "дані про висоту з OpenTopoData",
    "Weather" : "Погода",
    "Status" : "Статус",
    "Good morning" : "Доброго ранку",
    "Good morning, {name}" : "Доброго ранку, {name}",
    "Good afternoon" : "Добрий день",
    "Good afternoon, {name}" : "Добрий день, {name}",
    "Good evening" : "Добрий вечір",
    "Good evening, {name}" : "Добрий вечір, {name}",
    "Hello" : "Привіт",
    "Hello, {name}" : "Привіт, {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Почніть свій день інформовано \nІнформаційна панель Nextcloud — це ваша початкова точка дня, яка дає вам змогу огляд ваших майбутніх зустрічей, термінових електронних листів, повідомлень чату, вхідні квитки, останні твіти та багато іншого! Користувачі можуть додавати віджети вони люблять і змінюють фон на свій смак.",
    "Change background image" : "Змінити зображення тла",
    "Pick from Files" : "Виберіть із файлів",
    "Default images" : "Типові зображення",
    "Plain background" : "Однокольорове тло",
    "Insert from {productName}" : "Вставка з {productName}"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/uk.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Майстерня",
    "Dashboard app" : "Застосунок з панеллю віджетів ",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Почніть свій день з інформацією\n\nПанель управління Nextcloud — це ваша відправна точка на початку дня, яка надає огляд ваших майбутніх зустрічей, термінових електронних листів, повідомлень у чаті, вхідних квитків, останніх твітів та багато іншого! Користувачі можуть додавати вподобані віджети та змінювати фон на свій смак.",
    "Weather" : "Погода",
    "Status" : "Статус",
    "Good morning" : "Доброго ранку",
    "Good morning, {name}" : "Доброго ранку, {name}",
    "Good afternoon" : "Добрий день",
    "Good afternoon, {name}" : "Добрий день, {name}",
    "Good evening" : "Добрий вечір",
    "Good evening, {name}" : "Добрий вечір, {name}",
    "Hello" : "Привіт",
    "Hello, {name}" : "Привіт, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "З Днем народження 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "З Днем народження, {name} 🥳🤩🎂🎉",
    "Customize" : "Редагувати",
    "Edit widgets" : "Редагувати віджети",
    "Get more widgets from the App Store" : "Більше віджетів у каталозі застосунків",
    "Weather service" : "Погода",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Для забезпечення вашої конфіденційності дані про погоду запитуються вашим сервером Nextcloud від вашого імені, тому служба погоди не отримує особисту інформацію.",
    "Weather data from Met.no" : "Дані про погоду з Met.no",
    "geocoding with Nominatim" : "геокодування за допомогою Nominatim",
    "elevation data from OpenTopoData" : "дані про висоту з OpenTopoData"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
